---
title: "Metaphysical Realism - A Stream of Consciousness"
date: 2019-02-11T13:05:57Z
tags: ["metaphysics","dualism","empiricism","rationalism","realism","nominalism"]
topics: ["philosophy"]
image: /img/fabric-of-reality.jpg
draft: false
---

The following notes are an attempt at outlining my basic thought process, to document my progress in the study of metaphysical realism, and offer the reader some food for thought. I offer it, as is. If there are any actual arguments in this post, it is purely by accident. If there are any answers to the problem of realism within this text, the reader is free to take them.

**A (Very) Brief History of What Is**

The first question in metaphysics, the fundamental question, is “*What is there?*” Putting this more succinctly, in order to rely on fewer linguistic crutches, you could just say, “*What **is***?”. In order to answer this question — or even to imagine an answer is possible — we have to ask ourselves a few other questions first. To begin with, why is this *the* question?

Somehow, we are beings. Somehow, we are beings aware of being, and of our own being. What is that awareness, and why do we have it? Descartes[^1] took that awareness as axiomatic (a “*clear and distinct idea*“, in his terms). It was the fundamental feature of his entire ontology, famously captured as “*Cogito, Ergo Sum*“. Awareness, thinking, not only implies being, it *entails* it. Descartes speculated that sense experiences were just another kind of thinking: they are the ideas that come to us as sense experiences. Berkeley posited this speculation as a fact.[^2] Experiences *just are* ideas in the mind, including the mind of God. Locke[^3] agreed that sensations are ideas in the mind, but insisted in a world apart from those ideas, a mindless mechanical world, in which inhered powers to populate the mind with the ideas of experience. Our bodies function as a reception medium, upon which reality makes its impressions, and the mind records those impressions. There are whispers of Hume in this language.

Tying this back to the germ of “*awareness*“, it seems from the preceding paragraph, that there are two different forms of awareness taking shape: thoughtful awareness, and experiential awareness. This vague duality corresponds with several well known distinctions in philosophy. The “subject-object dichotomy”, the “analytic-synthetic” distinction, and the “rationalism-empiricism” distinction. Described in various ways, by various philosophers, these two forms of awareness are said to give us a complete set of tools for discovering “*what is*“. As I see it, then, the core dispute amongst metaphysicians of modern philosophy, has been over whether experiential awareness just collapses into thoughtful awareness, and whether it makes sense at all to talk about the being of things beyond the reach of either thoughtful or experiential awareness. In the first case, this is the argument between rationalists and empiricists. In the second case, this is the argument between the realists and the anti-realists. The realists, so-called counterintuitively, because they accept as “real”, any number of beings beyond the reach of thoughtful or experiential awareness. The anti-realist, so-called because he does not accept anything as real, other than what can be grounded in thoughtful or experiential awareness. The Idealist may find it hard to locate a fit for himself within this schema. On the one hand, the Berkeleyan Idealist will want to say that it makes no sense to talk of beings that are beyond the reach of thoughtful or experiential awareness, thus placing him in the anti-realist camp. The Platonic Idealist, on the other hand, could be seen as defending realism, as against Parmenides[^4], by insisting both that the Forms exist, and that they are beyond our worldly apprehension.

### How Do We Know?

Lurking in the background of this outline, lies a third major component. Namely, the problem of knowledge. When I speculate about tools for answering questions of an ontological nature, I am talking not just about whether the answers to those questions are true or false, as compared to a reality. I am also asking *how we know* “***what is***“? I have left it an unspoken assumption up to this point, that thoughtful and experiential awareness constitutes *knowledge of being*, whether that being is a complete entity or merely some particular property of a complete entity. Despite the confusing label of “*conceptual realist*“, Berkeley would deny that anything like an entity or properties of an entity could be known without an idea of it, because it is a bald absurdity to say that *what is unknown is also known*. On this basis, one could count Berkeley amongst the anti-realists, though also an idealist.

Empiricists like Locke seem far more willing to take certain beings as real, independently of any conception of them. Locke posited two kinds (“primary” and “secondary”) of properties of objects. His “secondary” properties were a kind of experiential awareness of an object that did not derive directly from the object, but from powers or features *hidden from experiential awareness*, yet inherent in the objects nonetheless. It is not hard to see why Berkeley would have had a complaint with Locke. How could he claim this reasonably, with no recourse to any demonstration, logical or empirical? The paradigm example of such a thing, is color. An apple is not red, says Locke, but hidden features of the apple and its surrounding environment conspire to produce the experiential awareness of red within our minds. Berkeley (I think rightly) asks, if we are going to posit such mechanisms for color or smell, then why not for shape, or heft, or motion, as well? He insists it is a distinction without a difference. If the idea of red is in the mind, then so is the idea of the shape of the apple, and the idea of it’s girth in our hand, and this is what makes the apple and all of its properties *real*.

As it turns out, later discoveries about light, the eye, and color have all apparently vindicated Locke over Berkeley. It is indeed a hidden feature of the apple, interacting with hidden features in the environment, that give us the experiential awareness of a red apple. However, further discoveries about the neurology of the eye and the brain, and subsequent discoveries about the quantum behaviors of light, that also seem to vindicate Berkeley. We know from neuroscience, for example, that experiential awareness is actually a coordinated composition of numerous asynchronous events. Nerve signals from the retina, from the ear drum, from the skin in our fingertips, from the olfactory nerves, and the tongue, all arrive in the brain as a more-or-less disordered collection of snap-together parts, often in different orders of arrangement and time, requiring the waiting for parts to complete the assembly of each moment of experiential awareness into a coherent composite image. This is often cited by determinists as a strong reason to reject free will (a question I will not address here). Why is this not also a strong reason to accept Berkeley’s “*conceptual realism*“? If this composite picture is not in fact, an *idea*, what is it?

But I digress. The present question, is what constitutes a justification for a claim that some entity or property is “real”? How can I make a claim about “what is” or “what is not”, that will carry at least the force of believability if not also deductive and epistemic certainty? The anti-realist insists not merely that an assertion about something be logically justifiable, but that it is also amenable to some sort of experiential validation. I cannot concoct just any story about what exists and have it accepted merely because I can demonstrate the validity of the logic. My story cannot be “*evidence transcendent*“[^5], as the philosophers like to say. To be true or false — to even be able to judge as true or false — my assertions must be subject to some sort of comparison with some sort of object of the senses. As the dominant epistemologists would say, they must be subject to validation by way of correspondence with a reality[^6] about which my assertions make reference. Parmenides’ complaint to Socrates comes to mind here. How could the gods know us, or we them, if the world of the gods is impenetrable by the sensible world of instances? Descartes’ “*clear and distinct idea*” is no help here, either, since it just reiterates this very problem.

### What Do We Mean?

The semantic philosophers would say that I am on the right track to ask about assertions, and what they mean, or in wondering how utterances about reality are justified in terms of their meaning. But I think this is a different problem than the questions I have been asking so far. The semantic philosophers are concerned with the assignment of a property to a *thought*. The description of a value belonging to a relationship between a thought and the object of that thought. They are unconcerned with objects beyond the fact that objects must be there to somehow give substance or experiential content to the relationship. A kind of equation: Thought == Object. (Interestingly, Hume frequently referred to events – both in reality, and in the mind – as “objects”[^7]). This is the structure that Blackburn gives to truth[^8]. Not so much a correspondence, as an equation. And he goes further than this. He wants to say that some objects come into being *by thier having been thought about*. Realizing the dangerous territory he is in, he is quick to draw clear lines of demarcation. Only certain things are “real” by virtue of our having thoughts of them; moral properties, or the value that inheres in money, for example. He calls this “quasi-realism”. In moral philosophy, this has come to be known as “projectivism”. This is different from Humean emotivism, because for Blackburn, the qualitative and quantitative value properties he’s describing *really do exist*. It’s just that the source of their existence is entirely mind-dependent. This mind-dependence is collective like Berkeley’s but it requires at least one human mind. For example, as long as at least one person sees the “value” in a dollar, the dollar *has that value*.

This question of the direction of flow between thought and object is fascinating to me. In Locke and Berkeley, it is fairly obvious that a substantive reality (be it a universal mind, or a mindless material) is producing experiences, and giving rise to the ideas of experiences, which we then express with varying degrees of specificity and accuracy with language. The only difference between Lockeans and Berkeleyans seems to be the nature of that substantive reality: is it mindless material governed by immutable laws in a mechanical clockwork universe, or is it a manifestation of the universal mind of God, intelligible to us because we share in that mind in some way? Both of these views puts the “ultimate” reality outside ourselves, while Blackburn wants to place at least some of it — or the responsibility for some aspects of it — squarely in our own minds. Does the source of an object or its properties affect how we answer “what is?” or even “is it real?” What sorts of properties constitute the full status of “real”? What things can be said to attain the property of existence (if being is a property, say, and not an absolute state)? For that matter, what is “existence”? The matrix of reality, within which individual beings are located? The “substrate” (as Berkeley’s Hylas would put it) that grounds all objects? Scientists (at least, the Einsteinians) would say, in a broad sense, that “existence” means some identifiable, finite accumulation of matter and energy at a locatable point in space-time. The planet Earth “exists”, for example. But this is too concrete, and thus too limiting, says someone like Blackburn. To say that because the value of a dollar has no spacio-temporal location, it therefore is non-existent, is to make us all into crazy people. So, returning to the question of direction, thoughtful and experiential awareness may be impressed by the objects in existence, or it may manifest the objects of existence, or both, or neither. Those are the choices, it seems. The last is some sort of extreme nihilism or Pyrrhonism. Locke (and Hume) take the first option, Berkeley takes the second, and Blackburn takes the third. Which of these is the correct choice?

### Truth, Meaning, and Being

Crispin Wright[^9] takes us one level up, and asks the meta-linguistic question of whether truth is a substantive property of thoughts. Wright argues for the “deflationist” view of truth, and his is the first explication of the position that didn’t seem to me to be nothing more than a truism, or a complaint of superfluousness. The deflationist, he says, isn’t just suggesting that we economize our use of phrases like “is true” by retreating to implication only. Rather, the deflationist is denying that truth is a property of sentences *at all*. He is saying that it is a “disquotational tool” for making an agreement between thinkers, explicit. Since truth is either the assignment or the identification of a value property to a relationship between thought (subject) and reality (object), this would make the deflationist a kind of anti-realist about truth.

It seems to me, there are at least three ways to think about this problem:

1. Truth is a real property of the relationship between thought and object, that only manifests in our asserted language through the disquotational device: “P is true, if and only if P”
2. Truth is a real property of the relationship between thought and object, and is manifest in our asserted language whether or not we employ the disquotational device: either “P” or “P is true, if and only if P”
3. Truth is not a real property of the relationship between thought and object, and any use of a disquotational device is misleading at best: “P” is merely the expression of an attitude or a

Perhaps it is misguided to attempt to apply the question “*what is?*” to such things as sentences, and the valence meanings applied to them. Do sentences “exists”? My use of phrases like “such things” suggests they do. What about thoughts? Can they have properties like an apple or a table? Can they have properties *unlike* an apple or a table? Can those properties be “primary” or “secondary”, as in Locke’s empiricism? The semantic philosophers are asking these questions from an analytical point of view (the view I have been taking throughout this post). But the questions have application *far* beyond understanding the instrumental components of linguistic meaning.

Applying my earlier question to the idea of truth makes this fairly clear: What is the “direction of flow” of the instantiation of these properties? Do we impose truth as a property on our relationship with reality? Is the relationship itself what imposes the truth? Is conceptualizing a “*relationship*” itself unreasonably imposing a meaning on experiential and thoughtful awareness? Where do we draw these lines, and why? More to the point, *how* do we draw these lines? Should we be drawing lines? As beings, as parts of the whole of being itself, there is the fundamental question of how it is we can tell the difference between the two, and even more significantly, how there can even be a difference? To put it in more concrete terms, how can mindless, mechanistic material being (the reality of Locke and Newton), give rise to a mindful, thoughtful, intentional beings? This is the kind of question that leads many philosophers into positions like animism, theism, and panpsychism.

### The End

One of the most frustrating features of the study of metaphysics, is it’s capacity to pull you down an endless rabbit hole, strip away all your certainties, dissolve all your boundaries, and leave you with endless questions, the answers to which you have almost no hope of answering. This disorienting effect, instinctively, sends most people screaming in the opposite direction. Many philosophers who are not metaphysicians, will simply draw lines arbitrarily, and insist we go no further than them. Scientists do this, too, for professional reasons. I can’t say that I blame them. There is great value in the mechanistic, dualistic view of the universe and our place within it. It has yielded many benefits to the human species. But the philosopher cannot help asking the question, “what if we’re wrong?”, and based on some of the work going on in physics and astronomy, it seems like we just might be.

```[Imported from exitingthecave.com on 29 November 2021]```

[^1]: [Discourse on Method, 1637](http://www.earlymoderntexts.com/assets/pdfs/descartes1637.pdf) 
[^2]: [Three Dialogues Of Hylas and Philonous, 1714](http://www.earlymoderntexts.com/assets/pdfs/berkeley1713.pdf)
[^3]: [Essay Concerning Human Understanding, 1689](http://www.earlymoderntexts.com/assets/pdfs/locke1690book1.pdf) 
[^4]: [Plato, The Parmenides](http://classics.mit.edu/Plato/parmenides.html) 
[^5]: [Realism, Stanford Encyclopedia of Philosophy](https://plato.stanford.edu/entries/realism/) 
[^6]: [Correspondence Theory of Truth, Stanford Encyclopedia of Philosophy](https://plato.stanford.edu/entries/truth-correspondence/) 
[^7]: [Treatise on Human Nature, 1739](http://www.earlymoderntexts.com/assets/pdfs/hume1739book1.pdf) 
[^8]: [Spreading The Word, 1984](https://global.oup.com/academic/product/spreading-the-word-9780198246510?cc=gb&lang=en&) 
[^9]: [Truth and Objectivity, 1994](http://www.hup.harvard.edu/catalog.php?isbn=9780674910874)
